/**
 * @file enum_cleanup.h
 *
 * @author  Guy Maurel Juli 2018
 * @license GPL v2+
 */
#ifndef ENUM_CLEANUP_H_INCLUDED
#define ENUM_CLEANUP_H_INCLUDED

/**
 * Scans through the whole list and does stuff.
 * works on the last comma within enum
 */
void enum_cleanup();

#endif /* ENUM_CLEANUP_H_INCLUDED */
